import React, { useEffect } from 'react';
import { Chart, registerables } from 'chart.js';

// Registra los módulos necesarios de Chart.js
Chart.register(...registerables);

const Tablero = ({ labels, dataPoints }) => {
    useEffect(() => {
        // Verifica si el canvas está disponible
        const canvas = document.getElementById("myChart");
        if (!canvas) {
            console.error("Canvas element not found");
            return;
        }

        const ctx = canvas.getContext("2d");
        
        // Verifica si el contexto es válido
        if (!ctx) {
            console.error("Failed to get canvas context");
            return;
        }

        // Datos del gráfico
        const data = {
            labels: labels,
            datasets: [{
                label: 'f(x)',
                borderColor: 'rgba(75, 192, 192, 1)',
                data: dataPoints,
                fill: false
            }]
        };

        // Configuración del gráfico
        const myChart = new Chart(ctx, {
            type: 'line',
            data: data,
            options: {
                scales: {
                    x: {
                        title: {
                            display: true,
                            text: 'X'
                        }
                    },
                    y: {
                        title: {
                            display: true,
                            text: 'f(x)'
                        }
                    }
                }
            }
        });

        // Limpieza del gráfico cuando el componente se desmonte
        return () => myChart.destroy();
    }, [labels, dataPoints]);

    return <canvas id="myChart" width="400" height="200"></canvas>;
};

export default Tablero;
